@@ -157,13 +157,13 @@ def test_cases(postersize, input_pagesize, output_pagesize, strategy, expected):
     blue = fitz.utils.getColor("blue")
     orange = fitz.utils.getColor("orange")
 
-    img.insertText(fitz.Point(97, 620), "A", fontsize=600, color=blue)
+    img.insert_text(fitz.Point(97, 620), "A", fontsize=600, color=blue)
     img.commit()
-    img.drawLine(fitz.Point(0, 0), fitz.Point(width, height))
+    img.draw_line(fitz.Point(0, 0), fitz.Point(width, height))
     img.finish(color=red)
-    img.drawLine(fitz.Point(0, height), fitz.Point(width, 0))
+    img.draw_line(fitz.Point(0, height), fitz.Point(width, 0))
     img.finish(color=green)
-    img.drawRect(fitz.Rect(fitz.Point(0, 0), fitz.Point(width, height)))
+    img.draw_rect(fitz.Rect(fitz.Point(0, 0), fitz.Point(width, height)))
     img.finish(color=orange)
     img.commit()
 
